CREATE EXTENSION IF NOT EXISTS "uuid-ossp";
CREATE TABLE IF NOT EXISTS "recommendations" (
	"rec_id" uuid PRIMARY KEY DEFAULT uuid_generate_v4(),
	"env" VARCHAR NOT NULL,
	"org_id" INTEGER NOT NULL,
	"policy_id" integer,
	"new_rule" JSON NOT NULL,
	"policy_type" TEXT NOT NULL CHECK (
		policy_type in ('sensor_policy', 'reputation_override')
	),
	"policy_subject" TEXT NOT NULL,
	"workflow" JSON,
	"impact" JSON,
	"show_in_ui" BOOLEAN NOT NULL DEFAULT false,
	UNIQUE (env, org_id, policy_type, policy_subject)
);
COMMENT ON COLUMN recommendations.rec_id IS 'Recommendation id';
COMMENT ON COLUMN recommendations.env IS 'CB Defense environment name';
COMMENT ON COLUMN recommendations.org_id IS 'CB Defense numeric org_id';
COMMENT ON COLUMN recommendations.policy_id IS 'CB Defense, env specific group/policy_id';
COMMENT ON COLUMN recommendations.new_rule IS 'json blob of the recommended rule';
COMMENT ON COLUMN recommendations.policy_type IS 'one of the following: "sensor_policy" or "reputation_override"';
COMMENT ON COLUMN recommendations.policy_subject IS 'the suject of the rule or policy';
COMMENT ON COLUMN recommendations.workflow IS 'workflow/lifecycles status the recommendation lifecycle';
COMMENT ON COLUMN recommendations.impact IS 'impact numbers for the recommendation';
COMMENT ON COLUMN recommendations.show_in_ui IS 'show_in_ui is a flag to enable the recommendation to show on the UI';
--TODO add index

delete from recommendations;
insert into recommendations
(rec_id,env, org_id, policy_id, new_rule, policy_type, policy_subject, workflow, impact, show_in_ui)
values(  'c306bc45-9b9e-4d1e-b265-fc6b2bbf5f42',
         'dev',
         123,
         3,
         '{"rule":{"sourceType":"APP","orgId":6756,"lastModification":"ADD","type":"IT_TOOL","csrAction":false,"value2":"False","env":"local","authListType":"WHITE_LIST","value1":"C:\\Program Files\\VMware\\VMware Tools\\vmtoolsd.exe","lastUpdatedTime":1589865429}}',
         'reputation_override',
         'C:\Program Files\VMware\VMware Tools\vmtoolsd.exe',
         '{"status":"new","email":"real_email@example.com","created_time":1680824118,"updated_time":1680824118,"ref_id":"","comment":""}',
         '{"other_orgs_with_rule":2,"impacted_device":26,"alert_count":0,"impact_score":3.14,"updated_time":1680824118}',
         true);
